==> seedsui-react-5.8.81.tgz: package/lib/Cascader/DistrictModal/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["value", "visible", "submitProps", "min", "isCountry", "isProvince", "isMunicipality", "isPrefecture", "isCity", "isDistrict", "isStreet", "setValueType", "type", "list", "loadData", "editableOptions"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useState, useEffect } from 'react';
import _ from 'lodash';
import { updateValueType, compareType, defaultSetValueType } from "./../DistrictMain/utils";
import DistrictMain from "./../DistrictMain";

// 内库使用
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// 级联选择
var DistrictModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var value = _ref.value,
    visible = _ref.visible,
    submitProps = _ref.submitProps,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? '' : _ref$min,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isPrefecture = _ref.isPrefecture,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet,
    _ref$setValueType = _ref.setValueType,
    setValueType = _ref$setValueType === void 0 ? defaultSetValueType : _ref$setValueType,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? '' : _ref$type,
    list = _ref.list,
    loadData = _ref.loadData,
    editableOptions = _ref.editableOptions,
    props = _objectWithoutProperties(_ref, _excluded);
  // 是否显示右上角确认按钮
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    submitVisible = _useState2[0],
    setSubmitVisible = _useState2[1];
  useEffect(function () {
    if (!visible || _.isEmpty(list) || _.isEmpty(value)) {
      min && setSubmitVisible(false);
      return;
    }
    updateSubmitVisible(value);

    // eslint-disable-next-line
  }, [visible]);

  // 更新value的type, 截取超出type部分
  function _updateValueType(newValue, newList) {
    var tabs = newValue || value;
    var data = newList || list;
    return updateValueType(tabs, data, {
      type: type,
      isCountry: isCountry,
      isProvince: isProvince,
      isMunicipality: isMunicipality,
      isPrefecture: isPrefecture,
      isCity: isCity,
      isDistrict: isDistrict,
      isStreet: isStreet,
      setValueType: setValueType
    });
  }

  // 根据min判断是否显示确定按钮
  function updateSubmitVisible(tabs) {
    var _tabs;
    if (!min || !Array.isArray(tabs) || !tabs.length) return;
    var submitVisible = null;

    // 获取末级类型
    _updateValueType(tabs);
    submitVisible = false;

    // 比较类型, 判断是否显示确定按钮
    var currentTypes = (_tabs = tabs[tabs.length - 1]) === null || _tabs === void 0 ? void 0 : _tabs.type;
    if (currentTypes) {
      var _iterator = _createForOfIteratorHelper(currentTypes),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var currentType = _step.value;
          if (compareType(currentType, min) >= 0) {
            submitVisible = true;
            break;
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
    setSubmitVisible(submitVisible);
  }

  // 点击选项前判断是否指定类型: 省, 市, 区
  function handleDrillDown(tabs) {
    updateSubmitVisible(tabs);
  }

  // 显示右上角的按钮
  // eslint-disable-next-line
  if (!submitProps) submitProps = {};
  if (submitVisible !== null) {
    // eslint-disable-next-line
    submitProps = _objectSpread({
      visible: submitVisible
    }, submitProps);
  }

  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  props.MainProps.type = type;
  props.MainProps.list = list;
  props.MainProps.loadData = loadData;
  props.MainProps.editableOptions = editableOptions;
  props.MainProps.isCountry = isCountry;
  props.MainProps.isProvince = isProvince;
  props.MainProps.isMunicipality = isMunicipality;
  props.MainProps.isPrefecture = isPrefecture;
  props.MainProps.isCity = isCity;
  props.MainProps.isDistrict = isDistrict;
  props.MainProps.isStreet = isStreet;
  props.MainProps.onChange = handleDrillDown;
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: ref,
    visible: visible,
    value: value
  }, props, {
    changeClosable: function changeClosable(newValue, newArguments, _ref2) {
      var submit = _ref2.submit;
      var lastTab = Array.isArray(newValue) && newValue.length ? newValue[newValue.length - 1] : null;
      if (lastTab !== null && lastTab !== void 0 && lastTab.isLeaf) {
        submit(newValue);
      }
    },
    submitProps: _objectSpread({
      visible: false
    }, submitProps || {}),
    className: "cascader-modal".concat(props.className ? ' ' + props.className : ''),
    MainComponent: DistrictMain
  }));
});
export default DistrictModal;

==> seedsui-react-5.8.90.tgz: package/lib/Cascader/DistrictModal/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["value", "visible", "submitProps", "min", "isCountry", "isProvince", "isMunicipality", "isPrefecture", "isCity", "isDistrict", "isStreet", "setValueType", "type", "list", "loadData", "editableOptions"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useState, useEffect } from 'react';
import _ from 'lodash';
import { updateValueType, compareType, defaultSetValueType } from "./../DistrictMain/utils";
import DistrictMain from "./../DistrictMain";

// 内库使用
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// 级联选择
var DistrictModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var value = _ref.value,
    visible = _ref.visible,
    submitProps = _ref.submitProps,
    _ref$min = _ref.min,
    min = _ref$min === void 0 ? '' : _ref$min,
    isCountry = _ref.isCountry,
    isProvince = _ref.isProvince,
    isMunicipality = _ref.isMunicipality,
    isPrefecture = _ref.isPrefecture,
    isCity = _ref.isCity,
    isDistrict = _ref.isDistrict,
    isStreet = _ref.isStreet,
    _ref$setValueType = _ref.setValueType,
    setValueType = _ref$setValueType === void 0 ? defaultSetValueType : _ref$setValueType,
    _ref$type = _ref.type,
    type = _ref$type === void 0 ? '' : _ref$type,
    list = _ref.list,
    loadData = _ref.loadData,
    editableOptions = _ref.editableOptions,
    props = _objectWithoutProperties(_ref, _excluded);
  // 是否显示右上角确认按钮
  var _useState = useState(null),
    _useState2 = _slicedToArray(_useState, 2),
    submitVisible = _useState2[0],
    setSubmitVisible = _useState2[1];
  useEffect(function () {
    if (!visible || _.isEmpty(list) || _.isEmpty(value)) {
      min && setSubmitVisible(false);
      return;
    }
    updateSubmitVisible(value);

    // eslint-disable-next-line
  }, [visible]);

  // 更新value的type, 截取超出type部分
  function _updateValueType(newValue, newList) {
    var tabs = newValue || value;
    var data = newList || list;
    return updateValueType(tabs, data, {
      type: type,
      isCountry: isCountry,
      isProvince: isProvince,
      isMunicipality: isMunicipality,
      isPrefecture: isPrefecture,
      isCity: isCity,
      isDistrict: isDistrict,
      isStreet: isStreet,
      setValueType: setValueType
    });
  }

  // 根据min判断是否显示确定按钮
  function updateSubmitVisible(tabs) {
    var _tabs;
    if (!min || !Array.isArray(tabs) || !tabs.length) return;
    var submitVisible = null;

    // 获取末级类型
    _updateValueType(tabs);
    submitVisible = false;

    // 比较类型, 判断是否显示确定按钮
    var currentTypes = (_tabs = tabs[tabs.length - 1]) === null || _tabs === void 0 ? void 0 : _tabs.type;
    if (currentTypes) {
      var _iterator = _createForOfIteratorHelper(currentTypes),
        _step;
      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var currentType = _step.value;
          if (compareType(currentType, min) >= 0) {
            submitVisible = true;
            break;
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    }
    setSubmitVisible(submitVisible);
  }

  // 点击选项前判断是否指定类型: 省, 市, 区
  function handleDrillDown(tabs) {
    updateSubmitVisible(tabs);
  }

  // 显示右上角的按钮
  // eslint-disable-next-line
  if (!submitProps) submitProps = {};
  if (submitVisible !== null) {
    // eslint-disable-next-line
    submitProps = _objectSpread({
      visible: submitVisible
    }, submitProps);
  }

  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  props.MainProps.type = type;
  props.MainProps.list = list;
  props.MainProps.loadData = loadData;
  props.MainProps.editableOptions = editableOptions;
  props.MainProps.isCountry = isCountry;
  props.MainProps.isProvince = isProvince;
  props.MainProps.isMunicipality = isMunicipality;
  props.MainProps.isPrefecture = isPrefecture;
  props.MainProps.isCity = isCity;
  props.MainProps.isDistrict = isDistrict;
  props.MainProps.isStreet = isStreet;
  props.MainProps.onChange = handleDrillDown;
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: ref,
    visible: visible,
    value: value
  }, props, {
    MainComponent: (props === null || props === void 0 ? void 0 : props.MainComponent) || DistrictMain,
    changeClosable: function changeClosable(newValue, newArguments, _ref2) {
      var submit = _ref2.submit;
      var lastTab = Array.isArray(newValue) && newValue.length ? newValue[newValue.length - 1] : null;
      if (lastTab !== null && lastTab !== void 0 && lastTab.isLeaf) {
        submit(newValue);
      }
    },
    submitProps: _objectSpread({
      visible: false
    }, submitProps || {}),
    className: "cascader-modal".concat(props.className ? ' ' + props.className : '')
  }));
});
export default DistrictModal;
